//  Diffusion Client Library for iOS, OS X and tvOS
//
//  Copyright (c) 2015, 2016 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;

@class PTDiffusionFieldMetadata;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief A field represents a single value in a record.
 
 A field object is immutable.
 
 @see PTDiffusionRecord
 @see PTDiffusionFieldMetadata

 @since 5.6
 */
@interface PTDiffusionField : NSObject <NSCopying>

-(instancetype)init NS_UNAVAILABLE;

/**
 The data defining the receiver.
 This returns the raw underlying bytes. It has not been transformed in any way.

 @since 5.6
 */
@property(nonatomic, readonly, copy) NSData* data;

/**
 The metadata defining the transformation that was applied to the receiver's data
 to produce the value.

 @since 5.6
 */
@property(nonatomic, readonly, copy, nullable) PTDiffusionFieldMetadata* metadata;

/**
 The value produced by applying the metadata to the data.
 If metadata is `nil` then this will return `nil`.
 
 The metadata defines the class of object returned by this method:
 - An `NSString` will be returned when transformed using PTDiffusionStringFieldMetadata.
 - Either an `NSNumber` or `NSDecimalNumber` will be returned when transformed using
   PTDiffusionNumberFieldMetadata, depending on the metadata's `scale`.

 @since 5.6
 */
@property(nonatomic, readonly, copy) id<NSObject, NSCopying, NSSecureCoding> value;

/**
 Compares the receiver to the given field.

 @param field The field object with which to compare the receiver.

 @return `YES` if the field is equal to the receiver, otherwise `NO`.

 @since 5.6
 */
-(BOOL)isEqualToField:(nullable PTDiffusionField *)field;

@end

NS_ASSUME_NONNULL_END
