//  Diffusion Client Library for iOS, OS X and tvOS
//
//  Copyright (c) 2016 Push Technology Ltd., All Rights Reserved.
//
//  Use is subject to license terms.
//
//  NOTICE: All information contained herein is, and remains the
//  property of Push Technology. The intellectual and technical
//  concepts contained herein are proprietary to Push Technology and
//  may be covered by U.S. and Foreign Patents, patents in process, and
//  are protected by trade secret or copyright law.

@import Foundation;

@class PTDiffusionPagedTopicOrder;
@class PTDiffusionPagedTopicRules;

NS_ASSUME_NONNULL_BEGIN

/**
 @brief An order key that specifies the sort ordering for a particular field
 within a record.
 
 @see PTDiffusionPagedRecordTopicDetailsBuilder
 @see PTDiffusionPagedRecordTopicOrderingPolicy

 @deprecated Since 5.9. Will be removed in a future release.

 @since 5.7
 */
__deprecated_msg("Will be removed in a future release.")
@interface PTDiffusionPagedRecordTopicOrderKey : NSObject <NSCopying>

-(instancetype)init NS_UNAVAILABLE;

/**
 Creates an order key specifying a field to sort, the sort order and any
 additional rules.
 
 @param fieldName The name of the field to sort on.
 
 @param order The order of sorting.
 
 @param rules Additional rules. If this is `nil` then no rules is assumed.
 
 @exception NSInvalidArgumentException If fieldName or order are `nil`.

 @since 5.7
 */
-(instancetype)initWithFieldName:(NSString *)fieldName
                           order:(PTDiffusionPagedTopicOrder *)order
                           rules:(nullable PTDiffusionPagedTopicRules *)rules NS_DESIGNATED_INITIALIZER;

/**
 The field name.

 @since 5.7
 */
@property(nonatomic, readonly) NSString* fieldName;

/**
 The order that the field is to be sorted into.

 @since 5.7
 */
@property(nonatomic, readonly) PTDiffusionPagedTopicOrder* order;

/**
 Additional rules used when sorting.

 - If `nil` then no additional rules are applied to ordering.
 - If not `nil` then supplied rules will be used.

 @since 5.7
 */
@property(nonatomic, readonly, nullable) PTDiffusionPagedTopicRules* rules;

/**
 Compares the receiver to the given paged record topic order key.

 @param pagedRecordTopicOrderKey The paged record topic order key object with which to compare the receiver.

 @return `YES` if the paged record topic order key is equal to the receiver, otherwise `NO`.

 @since 5.7
 */
-(BOOL)isEqualToPagedRecordTopicOrderKey:(nullable PTDiffusionPagedRecordTopicOrderKey *)pagedRecordTopicOrderKey;

@end

NS_ASSUME_NONNULL_END
